@@ -65,9 +65,9 @@ zend_function_entry swfed_functions[] = {
     PHP_ME(swfed,  replaceTagData, NULL, 0)
     PHP_ME(swfed,  getTagContentsByCID, NULL, 0)
     PHP_ME(swfed,  replaceTagContentsByCID, NULL, 0)
+
     PHP_ME(swfed,  getShapeData, NULL, 0)
     PHP_ME(swfed,  replaceShapeData, NULL, 0)
-    
     PHP_ME(swfed,  setShapeAdjustMode, NULL, 0)
     PHP_ME(swfed,  getShapeIdListByBitmapRef, NULL, 0)
     PHP_ME(swfed,  getBitmapSize, NULL, 0)
@@ -87,12 +87,15 @@ zend_function_entry swfed_functions[] = {
     PHP_ME(swfed,  disasmActionData, NULL, 0)
     PHP_ME(swfed,  setActionVariables, NULL, 0)
     PHP_ME(swfed,  replaceMovieClip, NULL, 0)
+
+    PHP_ME(swfed,  setCompressLevel, NULL, 0)
     PHP_ME(swfed,  swfInfo, NULL, 0)
+//    PHP_ME(swfed,  rebuild, NULL, 0)
     {NULL, NULL, NULL}	/* Must be the last line in swfed_functions[] */
 };
 /* }}} */
 
-#define SWFED_VERSION "0.34"
+#define SWFED_VERSION "0.35"
 
 /* {{{ swfed_module_entry
  */
@@ -329,6 +332,13 @@ PHP_METHOD(swfed, getHeaderInfo) {
         add_assoc_bool(return_value, "compress", 0);
     }
     add_assoc_long(return_value, "version", swf->header.version);
+
+    add_assoc_long(return_value, "x_min", swf->header_movie.frame_size.x_min / SWF_TWIPS);
+    add_assoc_long(return_value, "y_min", swf->header_movie.frame_size.y_min / SWF_TWIPS);
+    add_assoc_long(return_value, "x_max", swf->header_movie.frame_size.x_max / SWF_TWIPS);
+    add_assoc_long(return_value, "y_max", swf->header_movie.frame_size.y_max / SWF_TWIPS);
+    
+    
 }
 
 PHP_METHOD(swfed, setHeaderInfo) {
@@ -343,6 +353,8 @@ PHP_METHOD(swfed, setHeaderInfo) {
     }
     swf = get_swf_object(getThis() TSRMLS_CC);
     header_table = Z_ARRVAL_P(header_info);
+
+    // FWS or CWS
     if (zend_hash_find(header_table, "compress", sizeof("compress"), (void**)&tmp) == SUCCESS) {
         convert_to_boolean_ex(tmp);
         if (Z_LVAL_PP(tmp) != 0) {
@@ -352,10 +364,29 @@ PHP_METHOD(swfed, setHeaderInfo) {
         }
     }
 
+    // Version
     if (zend_hash_find(header_table, "version", sizeof("version"), (void**)&tmp) == SUCCESS) {
         convert_to_long_ex(tmp);
         swf->header.version = Z_LVAL_PP(tmp);
     }
+
+    // FrameRect
+    if (zend_hash_find(header_table, "x_min", sizeof("x_min"), (void**)&tmp) == SUCCESS) {
+        convert_to_long_ex(tmp);
+        swf->header_movie.frame_size.x_min = Z_LVAL_PP(tmp) * SWF_TWIPS;
+    }
+    if (zend_hash_find(header_table, "y_min", sizeof("y_min"), (void**)&tmp) == SUCCESS) {
+        convert_to_long_ex(tmp);
+        swf->header_movie.frame_size.y_min = Z_LVAL_PP(tmp) * SWF_TWIPS;
+    }
+    if (zend_hash_find(header_table, "x_max", sizeof("x_max"), (void**)&tmp) == SUCCESS) {
+        convert_to_long_ex(tmp);
+        swf->header_movie.frame_size.x_max = Z_LVAL_PP(tmp) * SWF_TWIPS;
+    }
+    if (zend_hash_find(header_table, "y_max", sizeof("y_max"), (void**)&tmp) == SUCCESS) {
+        convert_to_long_ex(tmp);
+        swf->header_movie.frame_size.y_max = Z_LVAL_PP(tmp) * SWF_TWIPS;
+    }
     RETURN_TRUE;
 }
 
@@ -1136,16 +1167,32 @@ PHP_METHOD(swfed, replaceMovieClip) {
     char *instance_name = NULL, *swf_data = NULL;
     int  instance_name_len = 0, swf_data_len = 0;
     swf_object_t *swf = NULL;
+    int unused_cid_purge = 1; // ǥե on
     int result = 0;
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ss",
-                              &instance_name, &instance_name_len,
-                              &swf_data, &swf_data_len) == FAILURE) {
-        RETURN_FALSE;
+    switch (ZEND_NUM_ARGS()) {
+      default:
+        WRONG_PARAM_COUNT;
+        RETURN_FALSE; /* XXX */
+      case 2:
+        if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ss",
+				  &instance_name, &instance_name_len,
+				  &swf_data, &swf_data_len) == FAILURE) {
+	  RETURN_FALSE;
+	}
+      break;
+      case 3:
+        if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ssb",
+				  &instance_name, &instance_name_len,
+				  &swf_data, &swf_data_len, &unused_cid_purge) == FAILURE) {
+	  RETURN_FALSE;
+	}
+	break;
     }
     swf = get_swf_object(getThis() TSRMLS_CC);    
     result = swf_object_replace_movieclip(swf, instance_name,
                                           instance_name_len,
-                                          swf_data, swf_data_len);
+                                          swf_data, swf_data_len,
+                                          unused_cid_purge);
     if (result) {
         RETURN_FALSE;
     }
@@ -1158,6 +1205,23 @@ PHP_METHOD(swfed, swfInfo) {
     RETURN_TRUE;
 }
 
+PHP_METHOD(swfed, rebuild) {
+    swf_object_t *swf = get_swf_object(getThis() TSRMLS_CC);
+    swf_object_rebuild(swf);
+    RETURN_TRUE;
+}
+
+PHP_METHOD(swfed, setCompressLevel) {
+    unsigned long compress_level = 6 ; // Z_DEFAULT_COMPRESSION
+    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC,
+                              "l", &compress_level) == FAILURE) {
+        RETURN_FALSE;
+    }
+    swf_object_t *swf = get_swf_object(getThis() TSRMLS_CC);
+    swf->compress_level = compress_level;
+    RETURN_TRUE;
+}
+
 static swf_object_t  *get_swf_object(zval *obj TSRMLS_DC) {
 //    zval *data, **tmp;
     zval **tmp = NULL;
