@@ -28,13 +28,14 @@ extern swf_action_info_t *get_swf_action_info(int action_id);
 
 extern int swf_action_parse(bitstream_t *bs, swf_action_t *act);
 extern int swf_action_build(bitstream_t *bs, swf_action_t *act);
-extern int swf_action_print(swf_action_t *act);
+extern int swf_action_print(swf_action_t *act, int indent_depth);
 
 extern swf_action_list_t *swf_action_list_create(bitstream_t *bs);
 extern unsigned char *swf_action_list_output(swf_action_list_t *list,
                                              unsigned long *length);
 extern void swf_action_list_destroy(swf_action_list_t *act_list);
-extern void swf_action_list_print(swf_action_list_t *act_list);
+extern void swf_action_list_print(swf_action_list_t *act_list,
+                                  int indent_depth);
 
 extern int swf_action_data_print(unsigned char *action_data,
                                  unsigned short action_data_len);
