@@ -17,6 +17,7 @@ typedef struct swf_object_ {
     swf_header_movie_t header_movie;
     swf_tag_t *tag;
     unsigned shape_adjust_mode;
+    unsigned compress_level;
 } swf_object_t;
 
 #define SWFED_SHAPE_BITMAP_NONE           0
@@ -31,6 +32,7 @@ extern unsigned char *swf_object_output(swf_object_t *swf, unsigned long *length
 
 /* --- */
 
+extern void swf_object_rebuild(swf_object_t *swf);
 extern void swf_object_print(swf_object_t *swf);
 extern unsigned char *swf_object_get_tagdata(swf_object_t *swf, int tag_seqno,
                                              unsigned long *length);
@@ -101,8 +103,8 @@ extern int swf_object_replace_movieclip(swf_object_t *swf,
                                         unsigned char *instance_name,
                                         int instancee_name_len,
                                         unsigned char *swf_data,
-                                        int swf_data_len);
-
+                                        int swf_data_len,
+                                        int unused_cid_purge);
 
 extern int swf_object_apply_shapematrix_factor(swf_object_t *swf,int shape_id,
                                                double scale_x, double scale_y,
