@@ -28,7 +28,8 @@ typedef struct my_png_buffer_ {
  * png read
  */
 
-static void png_data_read_func(png_structp png_ptr, png_bytep buf, png_size_t size) {
+static void
+png_data_read_func(png_structp png_ptr, png_bytep buf, png_size_t size) {
     my_png_buffer *png_buff = (my_png_buffer *)png_get_io_ptr(png_ptr);
     if (png_buff->data_offset + size <= png_buff->data_len) {
         memcpy(buf, png_buff->data + png_buff->data_offset, size);
@@ -49,7 +50,8 @@ static void png_data_read(png_structp png_ptr, my_png_buffer *png_buff) {
  * png write
  */
 
-void png_data_write_func(png_structp png_ptr, png_bytep buf, png_size_t size) {
+void
+png_data_write_func(png_structp png_ptr, png_bytep buf, png_size_t size) {
     my_png_buffer *png_buff = (my_png_buffer *)png_get_io_ptr(png_ptr);
     unsigned long new_data_len;
     if (png_buff->data_offset + size > png_buff->data_len) {
@@ -70,7 +72,8 @@ void png_data_write_func(png_structp png_ptr, png_bytep buf, png_size_t size) {
     png_buff->data_offset += size;
 }
 
-void png_data_write(png_structp png_ptr, my_png_buffer *png_buff) {
+void
+png_data_write(png_structp png_ptr, my_png_buffer *png_buff) {
     png_set_write_fn(png_ptr, (png_voidp) png_buff,
                      (png_rw_ptr)png_data_write_func, NULL);
 }
@@ -92,13 +95,17 @@ pngconv_png2lossless(unsigned char *png_data, unsigned long png_data_len,
     png_uint_32 png_width = 0, png_height = 0;
     volatile png_bytepp png_image_data = NULL;
     png_uint_32 x, y;
-    void *image_data;
+    void *image_data = NULL;
     png_color *palette = NULL;
     int palette_num = 0;
     png_bytep trans = NULL;
     int num_trans = 0;
     png_color_16p trans_values = NULL;
 
+    if (png_data == NULL) {
+        fprintf(stderr, "pngconv_png2lossless: png_data == NULL\n");
+        return NULL;
+    }
     is_png = png_check_sig((png_bytep)png_data, 8);
     if (! is_png) {
         fprintf(stderr, "pngconv_png2lossless: is not PNG!\n");
@@ -281,6 +288,10 @@ pngconv_lossless2png(void *image_data,
     volatile png_bytepp png_image_data = NULL;
     png_uint_32 x, y;
     volatile png_colorp png_palette = NULL;
+    if (image_data == NULL) {
+        fprintf(stderr, "pngconv_lossless2png: image_data == NULL\n");
+        return NULL;
+    }
     if ((format != 3) && (format != 5)) {
         fprintf(stderr, "jpegconv_lossless2png: format=%d not implemented yes.\n", format);
         return NULL;
